@@ -36,12 +36,12 @@
 #' olda
 #' plot_LDA(olda)
 #' @export
-Opn <- function(x, fac = dplyr::data_frame(), ldk = list()) {
+Opn <- function(x, fac = dplyr::tibble(), ldk = list()) {
   UseMethod("Opn")
 }
 
 #' @export
-Opn.default <- function(x, fac = dplyr::data_frame(), ldk = list()) {
+Opn.default <- function(x, fac = dplyr::tibble(), ldk = list()) {
   if (is_shp(x))
     Opn(list(x))
   else
@@ -50,7 +50,7 @@ Opn.default <- function(x, fac = dplyr::data_frame(), ldk = list()) {
 
 # for Momit and mom_df
 #' @export
-Out.data.frame <- function(x, fac = dplyr::data_frame(), ldk = list()){
+Out.data.frame <- function(x, fac = dplyr::tibble(), ldk = list()){
   # check if there is a coo column and initiate the Out
   .check(any(colnames(x)=="coo"),
          "data.frame must have a `coo` column")
@@ -86,7 +86,7 @@ Out.data.frame <- function(x, fac = dplyr::data_frame(), ldk = list()){
 }
 
 #' @export
-Opn.list <- function(x, fac = dplyr::data_frame(), ldk = list()) {
+Opn.list <- function(x, fac = dplyr::tibble(), ldk = list()) {
   x <- lapply(x, as.matrix)
   Opn <- structure(list(coo = x, fac = fac, ldk = ldk), class=c("Opn", "Coo"))
   if (!is.null(Opn$fac))
@@ -97,7 +97,7 @@ Opn.list <- function(x, fac = dplyr::data_frame(), ldk = list()) {
 }
 
 #' @export
-Opn.data.frame <- function(x, fac = dplyr::data_frame(), ldk = list()){
+Opn.data.frame <- function(x, fac = dplyr::tibble(), ldk = list()){
   # check if there is a coo column and initiate the Out
   .check(any(colnames(x)=="coo"),
          "data.frame must have a `coo` column")
@@ -125,7 +125,7 @@ Opn.data.frame <- function(x, fac = dplyr::data_frame(), ldk = list()){
 }
 
 #' @export
-Opn.array <- function(x, fac = dplyr::data_frame(), ldk = list()) {
+Opn.array <- function(x, fac = dplyr::tibble(), ldk = list()) {
   x <- a2l(x)
   Opn <- Opn(x, fac = fac, ldk = ldk)
   if (is.null(names(Opn))) names(Opn) <- paste0("shp", 1:length(Opn))
@@ -133,7 +133,7 @@ Opn.array <- function(x, fac = dplyr::data_frame(), ldk = list()) {
 }
 
 #' @export
-Opn.Coo <- function(x, fac = dplyr::data_frame(), ldk = list()) {
+Opn.Coo <- function(x, fac = dplyr::tibble(), ldk = list()) {
   Opn <- Opn(x = x$coo, fac = x$fac, ldk = x$ldk)
   if (is.null(names(Opn))) names(Opn) <- paste0("shp", 1:length(Opn))
   return(Opn)
@@ -189,7 +189,7 @@ Opn.Coo <- function(x, fac = dplyr::data_frame(), ldk = list()) {
 #' # all OpnCoe classes
 #' methods(class='OpnCoe')
 #' @export
-OpnCoe <- function(coe = matrix(), fac = dplyr::data_frame(), method = character(),
+OpnCoe <- function(coe = matrix(), fac = dplyr::tibble(), method = character(),
                    baseline1 = numeric(), baseline2 = numeric(), mod = list(),
                    r2 = numeric()) {
   if (missing(method))
