@@ -75,8 +75,8 @@ opoly.Opn <- function(x,
                                  nb.pts = 120,
                                  ...) {
   Opn <- x
-  # validates
-  Opn %<>% validate()
+  # verify
+  Opn %<>% verify()
   # we check a bit
   min.pts <- min(sapply(Opn$coo, nrow))
   if (nb.pts > min.pts) {
@@ -121,6 +121,11 @@ opoly.Opn <- function(x,
   return(res)
 }
 
+#' @rdname opoly
+#' @export
+opoly.list <- function(x, ...){
+  lapply(x, opoly, ...)
+}
 
 #' Calculate natural polynomial fits on open outlines
 #'
@@ -190,8 +195,8 @@ npoly.Opn <- function(x,
                       baseline2 = c(0.5, 0),
                       nb.pts = 120, ...) {
   Opn <- x
-  # validates
-  Opn %<>% validate()
+  # verify
+  Opn %<>% verify()
   # we check a bit
   min.pts <- min(sapply(Opn$coo, nrow))
   if (nb.pts > min.pts) {
@@ -236,6 +241,12 @@ npoly.Opn <- function(x,
   return(res)
 }
 
+#' @rdname npoly
+#' @export
+npoly.list <- function(x, ...){
+  lapply(x, npoly, ...)
+}
+
 #' Calculates shape from a polynomial model
 #'
 #' Returns a matrix of (x; y) coordinates when passed with a list obtained with
