@@ -17,17 +17,15 @@
 #' @param retain how many harmonics (or polynomials) to retain, for PCA
 #' the highest number of PC axis to retain, or the proportion of the variance to capture.
 #' @param drop how many harmonics (or polynomials) to drop
-#' @param verbose logical whether to print messages
 #' @return a list of matrices of (x,y) coordinates.
 #' @family multivariate
 #' @note Needs a review and should be considered as experimental.
+#' Silent message and progress bars (if any) with `options("verbose"=FALSE)`.
 #' @examples
 #' # MANOVA
-#' data(bot)
 #' bot.p <- PCA(efourier(bot, 12))
 #' MANOVA(bot.p, 'type')
 #'
-#' data(olea)
 #' op <- PCA(npoly(olea, 5))
 #' MANOVA(op, 'domes')
 #'
@@ -42,30 +40,29 @@
 #'  bot %>% efourier %>% PCA %>% MANOVA("cs")
 #'
 #' @export
-MANOVA <- function(x, fac, test = "Hotelling", retain, drop,
-                   verbose) {
+MANOVA <- function(x, fac, test = "Hotelling", retain, drop) {
   UseMethod("MANOVA")
 }
 
 #' @rdname MANOVA
 #' @export
 MANOVA.OpnCoe <- function(x, fac, test = "Hotelling", retain,
-                          drop, verbose = TRUE) {
+                          drop) {
   OpnCoe <- x
   if (length(OpnCoe$method) > 1)
     stop("cannot yet be used on combined OutCoe, do it manually")
   if (missing(fac))
     stop("'fac' must be provided")
-  if (!is.factor(fac)) {
-    fac <- OpnCoe$fac[, fac]
-  }
+
+  fac <- fac_dispatcher(x, fac)
+
   x <- OpnCoe$coe
   if (missing(drop))
     drop <- 0
   if (missing(retain))
     retain <- ncol(x)
   keep <- (drop + 1):retain
-  if (verbose)
+  if (.is_verbose())
     message("MANOVA done on:", colnames(x)[keep])
   mod <- summary(manova(x[, keep] ~ fac), test = test)
   return(mod)
@@ -73,15 +70,15 @@ MANOVA.OpnCoe <- function(x, fac, test = "Hotelling", retain,
 
 #' @rdname MANOVA
 #' @export
-MANOVA.OutCoe <- function(x, fac, test = "Hotelling", retain, drop, verbose = TRUE) {
+MANOVA.OutCoe <- function(x, fac, test = "Hotelling", retain, drop) {
   OutCoe <- x
   if (length(OutCoe$method) > 1)
     stop("cannot yet be used on combined OutCoe. Do it manually")
   if (missing(fac))
     stop("'fac' must be provided")
-  if (!is.factor(fac)) {
-    fac <- OutCoe$fac[, fac]
-  }
+
+  fac <- fac_dispatcher(x, fac)
+
   x <- OutCoe$coe
   cph <- NULL
   # we check for (a)symetrization
@@ -92,13 +89,13 @@ MANOVA.OutCoe <- function(x, fac, test = "Hotelling", retain, drop, verbose = TR
     if (sum(x[, BC]) == 0) {
       x <- x[, -BC]
       cph <- 2
-      if (verbose)
+      if (.is_verbose())
         message("B and C harmonics removed (because of removeAsymetric)")
     } else {
       if (sum(x[, AD]) == 0) {
         x <- x[, -AD]
         cph <- 2
-        if (verbose)
+        if (.is_verbose())
           message("A and D harmonics removed (because of removeSymetric)")
       }
     }
@@ -107,7 +104,7 @@ MANOVA.OutCoe <- function(x, fac, test = "Hotelling", retain, drop, verbose = TR
   if (missing(drop)) {
     if (OutCoe$norm) {
       drop <- 1
-      if (verbose)
+      if (.is_verbose())
         message("1st harmonic removed (because of normalization)")
     } else {
       drop <- 0
@@ -125,7 +122,7 @@ MANOVA.OutCoe <- function(x, fac, test = "Hotelling", retain, drop, verbose = TR
     if (retain > nb.h) {
       retain <- nb.h
     }
-    if (verbose) {
+    if (.is_verbose()) {
       message("'retain' was missing. MANOVA done with", retain, "harmonics ")
       if (drop > 0) {
         message("and the first", drop, "dropped")
@@ -137,10 +134,10 @@ MANOVA.OutCoe <- function(x, fac, test = "Hotelling", retain, drop, verbose = TR
       if (retain > nb.h) {
         retain <- nb.h
       }
-      if (verbose)
+      if (.is_verbose())
         message("'retain' was too ambitious. MANOVA done with ",
             retain, " harmonics ")
-      if (verbose) {
+      if (.is_verbose()) {
         if (drop > 0) {
           message("and the first ", drop, " were dropped")
         } else {
@@ -152,7 +149,7 @@ MANOVA.OutCoe <- function(x, fac, test = "Hotelling", retain, drop, verbose = TR
 
   harm.sel <- coeff_sel(retain = retain, drop = drop, nb.h = nb.h,
                         cph = cph)
-  if (verbose)
+  if (.is_verbose())
     message("\n")
   mod <- summary(manova(x[, harm.sel] ~ fac), test = test)
   return(mod)
@@ -160,27 +157,11 @@ MANOVA.OutCoe <- function(x, fac, test = "Hotelling", retain, drop, verbose = TR
 
 #' @rdname MANOVA
 #' @export
-MANOVA.PCA <- function(x, fac, test = "Hotelling", retain=0.99, drop, verbose = TRUE) {
+MANOVA.PCA <- function(x, fac, test = "Hotelling", retain=0.99, drop) {
   if (missing(fac))
     stop("'fac' must be provided")
 
-  if (class(fac) == "formula") {
-    column_name <- attr(terms(fac), "term.labels")
-    # we check for wrong formula
-    if (any(is.na(match(column_name, colnames(x$fac)))))
-      stop("formula provided must match with $fac column names")
-    # otherwise we retrive the column(s)
-    fac <- x$fac[, column_name]
-    # multicolumn/fac case
-    if (is.data.frame(fac))
-      fac <- factor(apply(fac, 1, paste, collapse="_"))
-  }
-
-  if (!is.factor(fac)) {
-    fac <- x$fac[, fac]
-  }
-
-
+  fac <- fac_dispatcher(x, fac)
 
   # we grab the PCs to capture retain% of the variance
   if (retain<1){
@@ -207,7 +188,6 @@ MANOVA.PCA <- function(x, fac, test = "Hotelling", retain=0.99, drop, verbose =
 #' pairwise combination of the factor provided.
 #' @param x a \link{PCA} object
 #' @param fac a name (or its id) of a grouping factor in \code{$fac} or a factor or a formula.
-#' @param verbose to feed \link{MANOVA}
 #' @param retain the number of PC axis to retain (1:retain) or the proportion of variance to capture (0.99 par default).
 #' @param ... more arguments to feed \link{MANOVA}
 #' @note Needs a review and should be considered as experimental.
@@ -219,19 +199,17 @@ MANOVA.PCA <- function(x, fac, test = "Hotelling", retain=0.99, drop, verbose =
 #' may be very long, see examples):
 #' \itemize{
 #'  \item manovas a list containing all the raw manovas
-#'  \item summary a matrix with all important statists
-#'  \item stars.tab a table with 'significance star', discutable but useful:
+#'  \item summary
+#'  \item stars.tab a table with 'significance stars', discutable but largely used:
 #'  '***' if Pr(>F) < 0.001; '**' of < 0.01; '*' if < 0.05; '.' if < 0.10 and '-' if above.
 #' }
 #' @examples
-#' data(bot)
 #' # we create a fake factor with 4 levels
 #' bot$fac$fake <- factor(rep(letters[1:4], each=10))
 #' bot.p <- PCA(efourier(bot, 8))
 #' MANOVA_PW(bot.p, 'fake') # or MANOVA_PW(bot.p, 2)
 #'
 #' # an example on open outlines
-#' data(olea)
 #' op <- PCA(npoly(olea))
 #' MANOVA_PW(op, 'domes')
 #' # to get the results
@@ -249,29 +227,17 @@ MANOVA_PW <- function(x, ...) {
 #' @export
 MANOVA_PW.PCA <- function(x,
                           fac,
-                          verbose = FALSE,
                           retain=0.99,
                           ...) {
   # preliminaries
   PCA <- x
 
   fac0 <- fac
+
   if (missing(fac))
     stop("'fac' must be provided")
 
-  if (class(fac) == "formula") {
-    #f0 <- PCA$fac[, attr(terms(fac), "term.labels")]
-    #fac <- interaction(f0)
-    fac <- x$fac[, attr(terms(fac), "term.labels")]
-    if (is.data.frame(fac))
-      fac <- factor(apply(fac, 1, paste, collapse="_"))
-  }
-
-  if (!is.factor(fac)) {
-    fac <- factor(PCA$fac[, fac])
-  } else {
-    fac <- droplevels.factor(fac)
-  }
+  fac <- fac_dispatcher(x, fac)
 
   # we grab the PCs to capture retain% of the variance
   if (retain<1){
@@ -290,7 +256,7 @@ MANOVA_PW.PCA <- function(x,
   x <- PCA$x[, retain]
 
   # we get all combinations, and prepare the loop
-  pws <- t(combn(levels(fac), 2))
+  pws <- t(utils::combn(levels(fac), 2))
   n <- nrow(pws)
   cn <- colnames(summary(manova(x~ fac))$stats)
   res <- matrix(NA, nrow = n, ncol = 6,
@@ -304,11 +270,11 @@ MANOVA_PW.PCA <- function(x,
       m <- summary(manova(x.i ~ fac.i))
       manovas[[i]] <- m
       res[i, ] <- m$stats[1, ]}
-    if (verbose)
+    if (.is_verbose())
       message(pws[i, ])
   }
   names(manovas) <- rownames(res)
-  # we prepare a 'signifance' table, with 'significant' stars
+  # we prepare a 'signifance' table, with 'significance' stars
   # (discutable but helpful) see stats:::print.summary.lm
   stars <- symnum(res[, 6], corr = FALSE, na = "?",
                   cutpoints = c(0, 0.001, 0.01, 0.05, 0.1, 1),
@@ -316,13 +282,14 @@ MANOVA_PW.PCA <- function(x,
   stars <- as.character(stars)
   nl <- nlevels(fac)
   # bloody ugly
-  stars.tab <- matrix(NA, nrow = nl - 1, ncol = nl,
+  pvalue.tab <- stars.tab <- matrix(NA, nrow = nl - 1, ncol = nl,
                       dimnames = list(levels(fac)[-nl], levels(fac)))
   stars.tab <- as.table(stars.tab)
   k <- 1
   for (i in 1:(nl - 1)) {
     for (j in (i + 1):nl) {
       stars.tab[i, j] <- stars[k]
+      pvalue.tab[i, j] <- res[, 6][k]
       k <- k + 1
     }
   }
@@ -330,12 +297,13 @@ MANOVA_PW.PCA <- function(x,
   print(stars.tab)
   cat("\n$summary (see also $manovas)\n")
   print(res, digits=4)
-  invisible(list(manovas = manovas, summary = res, stars.tab = stars.tab))
+  invisible(list(manovas = manovas, summary = res,
+                 stars.tab = stars.tab, pvalue.tab = pvalue.tab))
 }
 
 # #' @rdname MANOVA_PW
 # #' @export
-# MANOVA_PW.Coe <- function(x, fac, verbose = FALSE, ...) {
+# MANOVA_PW.Coe <- function(x, fac, ...) {
 #   # preliminaries
 #   Coe <- x
 #   fac0 <- fac
@@ -344,21 +312,21 @@ MANOVA_PW.PCA <- function(x,
 #   if (missing(fac))
 #     stop("'fac' must be provided")
 #   if (!is.factor(fac)) {
-#     fac <- Coe$fac[, fac]
+#     fac <- fac_dispatcher(Coe, fac)
 #   }
 #   # we get all combinations, and prepare the loop
-#   pws <- t(combn(levels(fac), 2))
+#   pws <- t(utils::combn(levels(fac), 2))
 #   n <- nrow(pws)
-#   cn <- colnames(MANOVA(Coe, fac, verbose = FALSE)$stats)
+#   cn <- colnames(MANOVA(Coe, fac)$stats)
 #   res <- matrix(NA, nrow = n, ncol = 6,
 #                 dimnames = list(paste(pws[, 1], pws[, 2], sep = " - "), cn))
 #   manovas <- list()
 #   # we loop and do all the MANOVAs
 #   for (i in 1:nrow(pws)) {
-#     if (verbose)
+#     if (.is_verbose())
 #       cat(pws[i, ], "\n")
 #     Coe.i <- subset(Coe, fac == pws[i, ])
-#     m <- MANOVA(Coe.i, fac0, verbose = verbose, ...)
+#     m <- MANOVA(Coe.i, fac0, ...)
 #     manovas[[i]] <- m
 #     res[i, ] <- m$stats[1, ]
 #   }
@@ -388,13 +356,5 @@ MANOVA_PW.PCA <- function(x,
 #   invisible(list(manovas = manovas, summary = res, stars.tab = stars.tab))
 # }
 
-# todo #' @rdname MANOVA #' @export MANOVA.LdkCoe <-
-# function(x, fac, test='Hotelling', retain, drop){ LdkCoe <-
-# x if (length(LdkCoe$method)>1) stop(' * cannot yet be used
-# on combined OutCoe. Do it manually.') if (missing(fac))
-# stop(' * 'fac' must be provided') if (!is.factor(fac)) {fac
-# <- LdkCoe$fac[, fac]} x <- LdkCoe$coe mod <-
-# summary(manova(x~fac), test=test) return(mod)}
-
 ##### end MANOVA
 
