@@ -8,12 +8,12 @@ test_that("Coo works fine", {
   expect_message(Coo())
   expect_message(Coo(bot$coo))
   expect_true(x %>% is_Coo())
-  expect_true(x %>% Opn() %>% validate %>% is_Coo())
-  expect_true(x %>% Ldk() %>% validate %>% is_Coo())
+  expect_true(x %>% Opn() %>% verify %>% is_Coo())
+  expect_true(x %>% Ldk() %>% verify %>% is_Coo())
 })
 
 test_that("Out works fine", {
-  expect_true(x %>% validate %>% is_Out())
+  expect_true(x %>% verify %>% is_Out())
   expect_true(x[1] %>% is_shp())
   expect_true(x[1] %>% is.matrix)
   expect_true(x[1:2] %>% is.list)
@@ -21,7 +21,7 @@ test_that("Out works fine", {
 
 test_that("Opn works fine", {
   x <- Opn(x)
-  expect_true(x %>% validate %>% is_Opn())
+  expect_true(x %>% verify %>% is_Opn())
   expect_true(x[1] %>% is_shp())
   expect_true(x[1] %>% is.matrix)
   expect_true(x[1:2] %>% is.list)
@@ -29,7 +29,7 @@ test_that("Opn works fine", {
 
 test_that("Ldk works fine", {
   x <- Ldk(x)
-  expect_true(x %>% validate %>% is_Ldk())
+  expect_true(x %>% verify %>% is_Ldk())
   expect_true(x[1] %>% is_shp())
   expect_true(x[1] %>% is.matrix)
   expect_true(x[1:2] %>% is.list)
